export declare const MISSING_API_KEY_ERROR_MESSAGE = "No API key found for Portkey.\nPlease set either the PORTKEY_API_KEY environment variable or pass the api_key in the to initialization of Portkey.\nAPI keys can be found or created at Portkey Dashboard \nHere's how you get it:\n1. Visit https://app.portkey.ai/\n1. Click on your profile icon on the top left\n2. From the dropdown menu, click on \"Copy API Key\"\n";
export declare const MISSING_BASE_URL = "No Base url provided. Please provide a valid base url.\nFor example: https://api.portkey.ai\n";
export declare const MISSING_CONFIG_MESSAGE = "The 'config' parameter is not set. Please provide a valid Config object";
export declare const MISSING_MODE_MESSAGE = "The 'mode' parameter is not set. Please provide a valid mode literal.";
export declare const INVALID_PORTKEY_MODE = "Argument of type '{}' cannot be assigned to parameter \"mode\" of type \"ModesLiteral | Modes | None\"\n";
export declare const DEFAULT_MAX_RETRIES = 2;
export declare const DEFAULT_TIMEOUT = 60;
export declare const PORTKEY_HEADER_PREFIX = "x-portkey-";
export declare const PORTKEY_BASE_URL = "https://api.portkey.ai";
export declare const PORTKEY_API_KEY_ENV = "PORTKEY_API_KEY";
export declare const PORTKEY_PROXY_ENV = "PORTKEY_PROXY";
