import { Fetch } from './baseClient';
export declare const safeJSON: (text: string) => any;
export declare const createResponseHeaders: (headers: Awaited<ReturnType<Fetch>>['headers']) => Record<string, string>;
export declare class Stream<Item> implements AsyncIterable<Item> {
    private response;
    private decoder;
    constructor(response: Response);
    private iterMessages;
    [Symbol.asyncIterator](): AsyncIterator<Item, any, undefined>;
}
