import * as Types from "./_types/portkeyConstructs";
import * as API from "./apis";
import { ApiClient } from "./baseClient";
interface ApiClientInterface {
    apiKey?: string | null;
    baseURL?: string | null;
    mode?: string | null;
    llms?: Array<Types.LLMOptions> | null;
    config?: string | null;
}
export declare class Portkey extends ApiClient {
    apiKey: string | null;
    baseURL: string;
    mode: string | null;
    llms: Array<Types.LLMOptions> | null;
    config: string | null;
    constructor({ apiKey, baseURL, mode, llms, config }: ApiClientInterface);
    protected constructLlms(llms?: Array<Types.LLMOptions> | null): Array<Types.LLMOptions> | null;
    completions: API.Completions;
    chatCompletions: API.ChatCompletions;
    generations: API.Generations;
}
export import LLMOptions = Types.LLMOptions;
export {};
