"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModelParamsList = void 0;
exports.ModelParamsList = [
    "model", "suffix", "max_tokens", "temperature", "top_k", "top_p", "n", "stop_sequences", "timeout", "functions", "function_call", "logprobs", "echo", "stop", "presence_penalty", "frequency_penalty", "best_of", "logit_bias", "user", "organization"
];
//# sourceMappingURL=portkeyConstructs.js.map