"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Generations = exports.Completions = exports.ChatCompletions = void 0;
var chatCompletions_1 = require("./chatCompletions");
Object.defineProperty(exports, "ChatCompletions", { enumerable: true, get: function () { return chatCompletions_1.ChatCompletions; } });
var completions_1 = require("./completions");
Object.defineProperty(exports, "Completions", { enumerable: true, get: function () { return completions_1.Completions; } });
var generations_1 = require("./generations");
Object.defineProperty(exports, "Generations", { enumerable: true, get: function () { return generations_1.Generations; } });
//# sourceMappingURL=index.js.map