"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApiResource = void 0;
class ApiResource {
    constructor(client) {
        this.client = client;
        this.post = client.post.bind(client);
    }
}
exports.ApiResource = ApiResource;
//# sourceMappingURL=apiResource.js.map