import { ModelParams } from "../_types/portkeyConstructs";
import { ApiResource } from "../apiResource";
import { APIPromise, RequestOptions } from "../baseClient";
export declare class Generations extends ApiResource {
    create(_body: GenerationsBody, opts?: RequestOptions): APIPromise<Generation>;
}
export interface GenerationsBody extends ModelParams {
    promptId: string;
    variables?: Record<string, any>;
}
export interface Generation {
    success: boolean;
    data: Record<string, any>;
}
