"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Completions = void 0;
const apiResource_1 = require("../apiResource");
class Completions extends apiResource_1.ApiResource {
    create(_body, opts) {
        var _a;
        const config = this.client.config || {
            mode: this.client.mode,
            options: this.client.llms
        };
        const body = {
            config,
            params: Object.assign({}, _body)
        };
        return this.post("/v1/complete", Object.assign(Object.assign({ body }, opts), { stream: (_a = _body.stream) !== null && _a !== void 0 ? _a : false }));
    }
}
exports.Completions = Completions;
//# sourceMappingURL=completions.js.map