type PlatformProperties = {
    "x-portkey-runtime"?: string;
    "x-portkey-runtime-version"?: string;
};
export declare const getPlatformProperties: () => PlatformProperties;
export declare const readEnv: (env: string) => string | undefined;
export declare const castToError: (err: any) => Error;
export {};
