"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Generations = void 0;
const apiResource_1 = require("../apiResource");
class Generations extends apiResource_1.ApiResource {
    create(_body, opts) {
        const config = this.client.config || {
            mode: this.client.mode,
            options: this.client.llms
        };
        const body = { "variables": _body.variables };
        return this.post(`/v1/prompts/${_body.promptId}/generate`, Object.assign({ body }, opts));
    }
}
exports.Generations = Generations;
//# sourceMappingURL=generations.js.map